package org.jharks.workflow;

import java.io.Serializable;


/**
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public abstract class AbstractProperty implements WorkFlowProperty, Serializable {

	private static final long serialVersionUID = 1L;
	
	/** The name of the property instance. */
    private String name;
    
    /**
     * Default public constructor: calls name argument constructor setting the 
     * property name to an empty string.
     */
    public AbstractProperty() {
        this("");
    }
    
    /**
     * Name argument constructor: sets property name to passed argument.
     * @param name The name of the property.
     */
    public AbstractProperty(String name)
    {
        if (name == null) 
            throw new IllegalArgumentException("Name cannot be null");
        this.name = name;
    }
    
    /**
     * @see WorkFlowProperty#getName()
     */
    public String getName()
    {
        return name;
    }

    /**
     * @see WorkFlowProperty#setName(String name)
     */
    public void setName(String name)
    {
        if (name == null) 
            throw new IllegalArgumentException("Name cannot be null.");
        this.name = name;
    }
    
    public int compareTo(AbstractProperty property)
    {
        //TODO: decide whether to actually build out compare
        //method passed on some sequence while building the 
        //AnswerContext.
        return 0;
    }
    
    /**
     * @see java.lang.Object#clone()
     */
    public Object clone()
    {
        try
        {
            AbstractProperty prop =
                (AbstractProperty) this.getClass().newInstance();
            prop.name = name;
  
            return prop;
        }
        catch (InstantiationException e)
        {
            return null;
        }
        catch (IllegalAccessException e)
        {
            return null;
        }
    }
    
    /**
     * Determines if the  objects are equal by comparing names and values
     *
     * @return true if names are equal and values are equal (or both null)
     */
    public boolean equals(Object o)
    {
        if (!(o instanceof AbstractProperty)) return false;
        if (this == o) return true;
        AbstractProperty apo = (AbstractProperty) o;
        if (!name.equals(apo.getName())) return false; 
        String s1 = getStringValue(); 
        String s2 = apo.getStringValue();
        return s1 == null ? s2 == null : s1.equals(s2);
    }
    
    /**
     * Returns a hash code for the property. Bases the hash
     * code on the name strings has and the value strings 
     * hash.
     */
    public int hashCode()
    {
        int result = 17;
        result = result * 37 + name.hashCode();// name cannot be null 
        String s = getStringValue();
        result = result * 37 + (s == null ? 0 : s.hashCode()); 
        return result;
    }

}
