package org.jharks.workflow;

import java.io.Serializable;
import java.util.Iterator;


/**
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class Answer implements Serializable {
	
	private static final long serialVersionUID = 1L;

	/** The value of a reponse */
    private Object value;
    
    /** The context for this object. */
    private AnswerContext context;
    
    /**
     * Constructs a new <CODE>Answer</CODE> object and sets the value
     * and context attributes.
     * @param context the answer context.
     * @param value the answer value.
     */
    public Answer(AnswerContext context, Object value) {
        this.context = context;
        this.value = value;
    }
    
    /**
     * Return the value store for this 
     * @return the value of the answer object.
     */
    public Object getValue() {
        return value;
    }
    
    /**
     * Return the context associated with the answer.
     * @return the associated answer context.
     */
    public AnswerContext getContext() {
        return (AnswerContext) context.clone();
    }
    
    /**
     * Check if object contains the specified <CODE>AnswerProperty</CODE>
     * any where in its context.
     * @param property The property to check. 
     * @return true if the property exists in the context. 
     */
    public boolean containsProperty(AnswerProperty property) {
        for (Iterator<AnswerProperty> it=context.getPropertyIterator(); it.hasNext(); ) {
            if (property.equals((AnswerProperty) it.next())) {
                return true;
            }  
        }
        return false;  
    }
    
    /**
     * Set the value of the object.
     * @param value the value of the response.
     */
    protected void setValue(Object value) {
        this.value = value;
    }
    
    /**
     * Set the context.
     * @param context the answer context.
     */
    protected void setContext(AnswerContext context) {
        this.context = context;
    }

}
