package org.jharks.workflow;

import java.io.Serializable;

/**
 * Key that identifies an <code>Answer</code> set within the responseMap of a
 * history object.
 * 
 * @author Michael J. Rizzo
 */
public class AnswerKey implements Serializable {

	private static final long serialVersionUID = 1L;
	
    /** The identifier for the associated question. */
    private String questionId;
    
    /** The identifier for the associated question group. */
    private String questionGroup;
    
    /**
     * Constructor that initiailes <code>AnswerKey</code> attributes.
     * @param questionId The question id.
     * @param questionGroup The name of the question group.
     */
    public AnswerKey(String questionId, String questionGroup) {
        if (questionId == null) 
            throw new IllegalArgumentException("ID cannot be null");
        this.questionId = questionId;
        this.questionGroup = questionGroup;
    }

    /**
     * Returns the name of the associated question group.
     * 
     * @return the question group name or null if not present.
     */
    public String getQuestionGroup() {
        return questionGroup;
    }

    /**
     * Sets the question group name.
     * 
     * @param questionGroup the name of the question group to set
     */
    public void setQuestionGroup(String questionGroup) {
        this.questionGroup = questionGroup;
    }

    /**
     * Returns the question id.
     * 
     * @return the question id.
     */
    public String getQuestionId() {
        return questionId;
    }

    /**
     * The question id to set.
     * 
     * @param questionId the question id to set.
     */
    public void setQuestionId(String questionId) {
        this.questionId = questionId;
    }
    
    /**
     * Determines if the objects are equal by comparing question id and group.
     *
     * @return true if question id and group are equal (or both empty).
     */
    public boolean equals(Object o)
    {
        if (o != null && (o.getClass().equals(this.getClass()))) {
          if (this == o) return true;
          AnswerKey key = (AnswerKey) o;
          if (!questionId.equals(key.getQuestionId())) return false; 
          String s1 = getQuestionGroup(); 
          String s2 = key.getQuestionGroup();
          return s1 == null ? s2 == null : s1.equals(s2);
        }
        
        return false;    
    }
    
    
    /**
     * Returns a hash code for the key. Bases the hash
     * code on the group name strings hash and the question id.
     * hash.
     */
    public int hashCode()
    {
        int result = 17;
        result = result * 37 + questionId.hashCode();// id cannot be null 
        String s = getQuestionGroup();
        result = result * 37 + (s == null ? 0 : s.hashCode()); 
        return result;
    }
}
