package org.jharks.workflow;

/**
 * Simple transition that allows for auto forwarding within 
 * <init> blocks.
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class AutoTransition extends Transition implements Cleanable {

    /** Indicates type of input */
    private String inputProperty = null;
    
    /** Flag indicating whether the transition is a clean up transition. */
    private boolean cleanUp = false;  
    
    /**
     * Default public constructor.
     */
    public AutoTransition() {
        super();
    }
    
    /**
     * Retrieve the clean up flag.
     * @return the clean up flag.
     */
    public boolean isCleanUp() {
        return this.cleanUp;
    }

    /**
     * Set the clean up flag for the transition.
     * @param flag the flag indicating whether the tranisition is a clean up 
     *        transition.
     */
    public void setCleanUp(boolean flag) {
        this.cleanUp = flag;
    }
    
    /**
     * Returns input property configured for queuable items.
     * @return Returns the input property configured.
     */
    public String getInputProperty() {
        return inputProperty;
    }
    
    /**
     * Set the input property for queuing.
     * @param property the input property.
     */
    public void setInputProperty(String property) {
        this.inputProperty = property;
    }
    
}
