package org.jharks.workflow;

/**
 * Interface to be implemented by transition that provides clean
 * up functionality.  Clean up consists of removing an empty
 * queue on the top of the queue stack and removing a session property
 * for the specified property.
 * @author Michael J. Rizzo
 * @version 1.0
 */
public interface Cleanable {

    /**
     * Retrieve the clean up flag.
     * @return the clean up flag.
     */
    public boolean isCleanUp();
    
    /**
     * Set the clean up flag for the transition.
     * @param flag the flag indicating whether the tranisition is a clean up 
     *        transition.
     */
    public void setCleanUp(boolean flag);
    
    /**
     * Returns input property configured for queuable items.
     * @return Returns the input property configured.
     */
    public String getInputProperty();
    
    /**
     * Set the input property for queuing.
     * @param property the input property.
     */
    public void setInputProperty(String property);
    
}
