package org.jharks.workflow;

import java.util.Iterator;
import java.util.List;

/**
 * Interface to be implemented by transition that provide queuing 
 * functionality.
 * @author Michael J. Rizzo
 * @version 1.0
 */
public interface Queueable {

    /**
     * Retrieve the queue flag.
     * @return the queue flag.
     */
    public boolean isQueueInput();
    
    /**
     * Set the queue input flag for the transition.
     * @param flag the flag indicating whether to queue input 
     *        within a transition.
     */
    public void setQueueInput(boolean flag);
    
    /**
     * Returns input property configured for queuable items.
     * @return Returns the input property configured.
     */
    public String getInputProperty();
    
    /**
     * Set the input property for queuing.
     * @param property the input property.
     */
    public void setInputProperty(String property);
    
    /**
     * Returns input value configured for the queuable item.
     * @return Returns the configured input value.
     */
    public String getInputValue();
    
    /**
     * Set the input type value for queued object.
     * @param value the input value.
     */
    public void setInputValue(String value);
    
    /**
     * Returns the queue by alais.
     * @return the queue by alias.
     */
    public String getQueueBy();
    
    /**
     * Set the grouping to use when loading elements onto the queue.
     * @param queueBy The queueBy to set.
     */
    public void setQueueBy(String queueBy);
    
    /**
     * Return the question id that indicates which question responses
     * within the <CODE>ResponseSet</CODE> should be queued. 
     * @return Returns the queueQuestionId.
     */
    public String getQueueQuestionId();
    
    /**
     * Set the question id filter for queuing responses.
     * @param queueQuestionId The queueQuestionId to set.
     */
    public void setQueueQuestionId(String queueQuestionId);
    
    /**
     * Add a <CODE>QueueFilter</CODE> object for the transition.
     * @param vf <CODE>QueueFilter</CODE> object to add.
     */
    public void addFilter(QueueFilter vf);
    
    /**
     * Retrieve iterator for filters.
     * @return filter iterator.
     */
    public Iterator<QueueFilter> filterIterator();
    
    /**
     * The method allows for the retrieval of the entire collection of 
     * <CODE>QueueFilter</CODE> instances on a <CODE>Transition</CODE> object.
     * @return List of <CODE>QueueFilter</CODE> instances.
     */
    public List<QueueFilter> getFilters();
}
