package org.jharks.workflow;

import java.util.List;

/**
 * The RuleSet class will be a container for a set of <CODE>Rule</CODE> 
 * instances.  When configuring a <CODE>Transition</CODE> a 
 * <CODE>RuleSet</CODE> can be associated with the object.  All rules 
 * would need to be met within a <CODE>RuleSet</CODE> for the 
 * transition to be executed.  
 * 
 * @author Michael J. Rizzo
 */

public class RuleSet {

    /** Default public constructor */
    public RuleSet() {
    }

    /** List of <CODE>Rules</CODE> configured. */
    private List<Rule> rules;

    /**
     * Retrieve a collection as a List of all <CODE>Rule</CODE> 
     * instances within a <CODE>RuleSet</CODE>.
     */
    public List<Rule> getRules() {
        return rules;
    }

    /**
     * Set rules.
     * @param value the list of <CODE>Rule</CODE> instances.
     */
    public void setRules(List<Rule> value) {
        this.rules = value;
    }

    /**
     * Add a <CODE>Rule</CODE> instance to a <CODE>RuleSet</CODE>. 
     * @param rule the <CODE>Rule</CODE> instance to add.
     */
    public void addRule(Rule rule) {
        rules.add(rule);
    }
}
