package org.jharks.workflow;

/**
 * Contains methods to be implemented by stackable elements. All items
 * to be placed on the <CODE>SessionHistory</CODE> queue stack should 
 * implement <CODE>Stackable</CODE>. 
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public interface Stackable {
    
    /**
     * Returns the type of a stackable survey element.
     * @return the element type.
     */
    public String getElementType();
    
    /** 
     * Return the value to which to set a session property.
     * @return value to which view property will be set to when iterating.
     */
    public String getPropertyValue();
    
    /**
     * Sets the data object of the stackable survey element.
     * @param item the data object.
     */
    public void setStackObject(Object item);
    
    /**
     * Returns the associated data object of the stackable survey element.
     * @return the data object.
     */
    public Object getStackObject();
    
    public int queueSize();
}
