package org.jharks.workflow.actions;

import org.jharks.workflow.Action;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.WorkFlowContext;
import org.jharks.workflow.exception.WorkFlowActionException;

/**
 * Action used to remove (unset) a property on the 
 * <code>SessionHistory</code> instance.
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class RemoveSessionPropertyAction extends Action {

    /** The name of the proprety to set. */
    private String sessionPropertyName;
    
    /**
     * @see org.jharks.workflow.Action#apply(java.lang.Object)
     */
    public void apply(Object input)throws WorkFlowActionException {
      if (input instanceof WorkFlowContext) {
    	  WorkFlowContext workFlowContext = (WorkFlowContext) input;
          SessionHistory sh = workFlowContext.getHistory();
          
          if (logger.isDebugEnabled())
              logger.debug("Removing session property: " +
                    "property name = " + getSessionPropertyName());
          
          sh.removeProperty(getSessionPropertyName());
      } else {
          throw new ClassCastException("Expecting SessionHistory Object.");
      }
    }
    
    /**
     * Returns the name of the session property configured to check.
     * @return the name of the session property to check.
     */
    public String getSessionPropertyName() {
        return sessionPropertyName;
    }
    
    /**
     * Sets the session property name.
     * @param sessionPropertyName The session property name to set.
     */
    public void setSessionPropertyName(String sessionPropertyName) {
        this.sessionPropertyName = sessionPropertyName;
    }
}
