package org.jharks.workflow.actions;

import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.WorkFlowContext;
import org.jharks.workflow.exception.WorkFlowActionException;

/**
 * Action used to set a property on the <code>SessionHistory</code> instance.
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class SetSessionPropertyAction extends RemoveSessionPropertyAction {

    /** The value to be set for the property. */
    private String sessionPropertyValue;
    
    /**
     * @see org.jharks.workflow.Action#apply(java.lang.Object)
     */
    public void apply(Object input) throws WorkFlowActionException {
      if (input instanceof WorkFlowContext) {
    	  WorkFlowContext workFlowContext = (WorkFlowContext) input;
          SessionHistory sh = workFlowContext.getHistory();
          
          if (logger.isDebugEnabled())
              logger.debug("Setting session property: " +
                    "property name = " + getSessionPropertyName());
          
          sh.setProperty(getSessionPropertyName(), getSessionPropertyValue());
      } else {
          throw new ClassCastException("Expecting SessionHistory Object.");
      }
    }
   
    /**
     * Returns the configured value of the session property value to check.
     * @return the session property value that was configured.
     */
    public String getSessionPropertyValue() {
        return sessionPropertyValue;
    }
    
    /**
     * Sets the session property value attribute to the specified value.
     * @param sessionPropertyValue The session property value to set.
     */
    public void setSessionPropertyValue(String sessionPropertyValue) {
        this.sessionPropertyValue = sessionPropertyValue;
    }
}
