package org.jharks.workflow.conditions;

import java.util.List;

import org.jharks.workflow.Answer;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.util.WorkFlowUtilities;


/**
 * @author mrizzo
 *
 */
public class BooleanMatchCondition extends StringMatchCondition {
    
	/**
     * @see org.jharks.workflow.RuleCondition#checkCondition(
     *      java.lang.Object)
     */
    public boolean checkCondition(Object param) {
    	 boolean result = false;    
         if (logger.isDebugEnabled())
               logger.debug("BooleanMatchCondition: Check condition: " +
                     "questionId = " + getQuestionId());
               
         if (param instanceof SessionHistory) {
             SessionHistory rs = (SessionHistory) param;
             
             if (logger.isDebugEnabled())
                 logger.debug(this.getClass().getName() + 
                         ": using current context = " + isUseContext());
             
             List<Answer> responses = rs.getResponses(getQuestionId(), 
                     getQuestionGroup(), isUseContext());
                 
             if (responses != null) {
               if (logger.isDebugEnabled())
                   logger.debug ("Size response set " + responses.size());
               
               for (int i=0; i < responses.size(); i++) {
                   result = compare(responses.get(i));
                   if (result) break;
               }
             }
         } else {
             throw new ClassCastException("Expecting SessionHistory Object.");
         }
       return result;
    }
	
    /**
     * Compare method to check equivalence of strings.
     * @param response the response for the configured question.
     * @return true if response matches value property.
     */
    private boolean compare(Object response) {
       
       Object answerValue = WorkFlowUtilities.getAnswerValue(response); 
        
       if ((answerValue.getClass().getName().equals(Boolean.TYPE)) || ( answerValue 
         instanceof Boolean )) {
           if( logger.isDebugEnabled() )
             logger.debug("BooleanMatchCondition: comparison value = [" 
               + getValue() + "]: response value = [" 
               + answerValue + "]");
             
           boolean boolAnswer = ((Boolean) answerValue).booleanValue();
           Boolean boolCompare = new Boolean(getValue());
           if (boolAnswer && boolCompare) return true;
           if (!boolAnswer && !boolCompare) return true;
           return false;
       } else {
           throw new ClassCastException("Expecting String Object.");
       }
    }
}
