package org.jharks.workflow.conditions;


import java.util.EmptyStackException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.Stackable;


/**
 * This <CODE>RuleCondition</CODE> peeks into the stack of queues
 * on the <CODE>SessionHistory</CODE> object and checks to see 
 * the specified queue is on the top of the stack and is currently
 * empty.
 *
 * For example, to check whether the next queue on the stack is of type
 * <code>Problem Class</code> and currently empty you could configure a 
 * <code>rule-condition</code>
 * as:
 * <pre>
 *    &lt;rule-condition type="org.jharks.workflow.conditions.
 *                             EmptyQueueCondition"&gt;
 *      &lt;property name="category" value="Problem Class"/&gt;
 *    &lt;/rule-condition&gt;
 * </pre>
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class EmptyQueueCondition extends QueueTypeCondition {

    /** The logger for the module. */
    protected Log logger = LogFactory.getLog(getClass().getName());
    
    /**
     * @see org.jharks.workflow.RuleCondition#checkCondition(java.lang.Object)
     */
    public boolean checkCondition(Object param) {
        if (param instanceof SessionHistory) {
            SessionHistory sh = (SessionHistory) param;
            Stackable element = null;
            
            try {
              element = sh.peek();
            } catch (EmptyStackException ese) {
              logger.info("No queues left on the stack: EmptyQueueCondition " +
                    "is satisfied: " + ese.getMessage());
              return true;
            }
            
            if (element.getElementType().equalsIgnoreCase(getCategory()) && 
                    element.queueSize() == 0)
                return true;
                
        } else {
            throw new ClassCastException("Expecting SessionHistory Object.");
        }
        return false;
    }

}
