package org.jharks.workflow.conditions;

/**
 * This <CODE>RuleCondition</CODE> peeks into the stack of queues
 * on the <CODE>SessionHistory</CODE> object and checks to see 
 * the specified queue is on the top of the stack and has a node
 * waiting to be dequeued.
 *
 * For example, to check whether the next queue on the stack is of type
 * <code>Problem Class</code> and currently has, at least one node, 
 * queue waiting to be dequeue you could configure a 
 * <code>rule-condition</code>
 * as:
 * <pre>
 *    &lt;rule-condition type="org.jharks.workflow.conditions.
 *                             NonEmptyQueueCondition"&gt;
 *      &lt;property name="category" value="Problem Class"/&gt;
 *    &lt;/rule-condition&gt;
 * </pre>
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class NonEmptyQueueCondition extends EmptyQueueCondition {

    /**
     * @see org.jharks.workflow.RuleCondition#checkCondition(
     *      java.lang.Object)
     */
    public boolean checkCondition(Object param) {
       return ( super.checkCondition(param) == true )? false : true;
    }
    
}
