package org.jharks.workflow.conditions;

import org.jharks.workflow.SessionHistory;

/**
 * Condition that checks if the current session proeprty matches
 * the specifed value.
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class SessionPropertyMatchCondition extends SessionPropertySetCondition {
    
    /** The value to be matched against the property value. */
    private String sessionPropertyValue;
    
    /**
     * @see org.jharks.workflow.RuleCondition#checkCondition(java.lang.Object)
     */
    public boolean checkCondition(Object param) {
        if (logger.isDebugEnabled())
            logger.debug("SessionPropertyMatchCondition: Check condition: " +
                  "property name = " + getSessionPropertyName());
            
      if (param instanceof SessionHistory) {
          SessionHistory rs = (SessionHistory) param;
  
          if ( checkProperty(getSessionPropertyName(), rs) != null ) {
              Object property = rs.getProperty(getSessionPropertyName());
              
              if (property instanceof String) {
                if (logger.isDebugEnabled()) {
                  logger.debug("Session Property value = [" +  property + "]");
                  logger.debug("Configured value = [" 
                          + getSessionPropertyValue() + "]");
                }
              
                if (((String) property).equalsIgnoreCase(
                      getSessionPropertyValue()))
                  return true;
              } else {
                if ( property.equals(getSessionPropertyValue()) )
                      return true;
              }
          }
      } else {
          throw new ClassCastException("Expecting SessionHistory Object.");
      }
        return false;
    } 
    
    
    /**
     * Returns the configured value of the session property value to check.
     * @return the session property value that was configured.
     */
    public String getSessionPropertyValue() {
        return sessionPropertyValue;
    }
    
    /**
     * Sets the session property value attribute to the specified value.
     * @param sessionPropertyValue The session property value to set.
     */
    public void setSessionPropertyValue(String sessionPropertyValue) {
        this.sessionPropertyValue = sessionPropertyValue;
    }
}
