package org.jharks.workflow.conditions;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jharks.workflow.RuleCondition;
import org.jharks.workflow.SessionHistory;


/**
 * Checks to see whether the specified property is currently set
 * in the property map of the <code>SessionHistory</code> instance.
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class SessionPropertySetCondition extends RuleCondition {

    /** The name of the property to check. */
    private String sessionPropertyName;
    
    /** The logger for the module. */
    protected Log logger = LogFactory.getLog(getClass().getName());
    
    /**
     * @see org.jharks.workflow.RuleCondition#checkCondition(java.lang.Object)
     */
    public boolean checkCondition(Object param) {
        if (logger.isDebugEnabled())
            logger.debug("SessionPropertySetCondition: Check condition: " +
                  "property name = " + getSessionPropertyName());
            
      if (param instanceof SessionHistory) {
          SessionHistory rs = (SessionHistory) param;
            if (checkProperty(getSessionPropertyName(), rs) != null) 
                return true;
      } else {
          throw new ClassCastException("Expecting SessionHistory Object.");
      }
        return false;
    } 

    /**
     * Returns the name of the session property configured to check.
     * @return the name of the session property to check.
     */
    public String getSessionPropertyName() {
        return sessionPropertyName;
    }
    
    /**
     * Sets the session property name.
     * @param sessionPropertyName The session property name to set.
     */
    public void setSessionPropertyName(String sessionPropertyName) {
        this.sessionPropertyName = sessionPropertyName;
    }
    
    /**
     * Method that return the property value the exists in the 
     * <code>SessionHistory</code> instance or null if the property
     * doesn't exist.
     * @param propertyName the property to retrieve.
     * @param history a <code>SessionHistory</code> instance. 
     * @return the property value.
     */
    protected Object checkProperty(String propertyName, SessionHistory history) {
        return history.getProperty(propertyName);
    }
}
