package org.jharks.workflow.exception;

import java.io.PrintStream;
import java.io.PrintWriter;

/**
 * Represents an exception the occurs within the workflow component.
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class WorkFlowException extends RuntimeException {

    private static final long serialVersionUID = 1L;
	
    /**
     * Original exception which caused this exception.
     */
    protected Throwable originalException;
    
    /**
     * Create a <code>WorkFlowException</code> and set the exception error
     * message.
     *
     * @param message the message of the exception.
     */
    public WorkFlowException(String message) {
        this(message, null);
    }

    /**
     * Create a <code>WorkFlowException</code>, and set exception
     * object that caused this exception.  The message is set by default to be
     * the one from the original exception.
     * @param cause the original exception.
     */
    public WorkFlowException(Throwable cause) {
        super(cause.getMessage());
        this.originalException = cause;
    }

    /**
     * Create a <code>WorkFlowException</code>, set the exception error
     * message along with the exception object that caused this exception.
     * @param message the detail of the error message.
     * @param cause the original exception.
     */
    public WorkFlowException(String message, Throwable cause) {
        super(message);
        this.originalException = cause;
    }
    
    /**
     * Print the full stack trace, including the original exception.
     */
    public void printStackTrace()
    {
        printStackTrace(System.err);
    }

    /**
     * Print the full stack trace, including the original exception.
     *
     * @param ps the byte stream in which to print the stack trace
     */
    public void printStackTrace(PrintStream ps)
    {
        super.printStackTrace(ps);

        if (this.originalException != null)
        {
            this.originalException.printStackTrace(ps);
        }
    }

    /**
     * Print the full stack trace, including the original exception.
     *
     * @param pw the character stream in which to print the stack trace
     */
    public void printStackTrace(PrintWriter pw)
    {
        super.printStackTrace(pw);

        if (this.originalException != null)
        {
            this.originalException.printStackTrace(pw);
        }
    }


}
