package org.jharks.workflow.handlers;

import java.text.SimpleDateFormat;
import java.util.Date;

import org.jharks.workflow.AnswerValueHandler;


/**
 * A value handler the outputs <code>java.util.date</code> instances
 * in a standard format.  A format string can be specified in the 
 * workflow.properties file.  The pattern syntax for date formats
 * is the same that is used for the standard 
 * <code>java.text.SimpleDateFormat</code> class.
 * @see java.text.SimpleDateFormat
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class DateValueHandler extends AbstractValueHandler 
    implements AnswerValueHandler {

    /** The default format to use when generating the persistable format. */
    private static final SimpleDateFormat defaultFormat = new SimpleDateFormat("MM/dd/yyyy hh:mm");
    
    /**
     * Default public constructor.
     */
    public DateValueHandler() {
    }

    /**
     * @see org.jharks.workflow
     * .AnswerValueHandler#format(java.lang.Object)
     */
    public String format(Object value) {
        
        Date dateValue = (Date) value;
        
        String configuredFormat = wc.getProperty("default.date.format");
        if (configuredFormat != null ) {
            SimpleDateFormat sdf = new SimpleDateFormat(configuredFormat);
            return sdf.format(dateValue).toString();     
        } else {
            return defaultFormat.format(dateValue).toString();
        }
    }

    /**
     * @see org.jharks.workflow
     * .AnswerValueHandler#getHandlerType()
     */
    public String getHandlerType() {
        return "java.util.Date";
    }

}
