package org.jharks.workflow.loaders;

import java.util.Iterator;

import org.jharks.workflow.Loader;
import org.jharks.workflow.LoaderConfig;
import org.jharks.workflow.QueueFilter;
import org.jharks.workflow.Queueable;
import org.jharks.workflow.WorkFlowConstants;



/**
 * Abstract class that contains common methods for queue loader
 * implementations.  Queue loader implementaions are used to 
 * populate the queue data structure on a <code>SessionHistory</code>
 * instance.
 * @author Michael J. Rizzo
 */
public abstract class AbstractQueueLoader extends Loader {
    
    /**
     * Filters values out of a queueable set.  If the response value
     * equals a filter value, the response will be dropped from the 
     * set and will not be queued.
     * 
     * @param responseValue the filter response value.
     * @param config a loader configuration object.
     * @return true if response should be filtered. 
     */
    protected boolean filter(String responseValue, LoaderConfig config) {
        if (config == null || config.filterIterator() == null) return false;
        
        for (Iterator<QueueFilter> itr=config.filterIterator(); itr.hasNext(); ) {
            QueueFilter filterValue = itr.next();
            if (responseValue.equals(filterValue.getValue())) return true;
        }
        return false;
    }
    
    /**
     * Inspects the passed transition and uses the configured type or
     * sets type to generic.
     * 
     * @param tr the transition currently being processed.
     * @return the set item type for queue nodes.
     */
    protected String setType(Queueable tr) {
        String itemType = WorkFlowConstants.GEN_CATEGORY;
        
        if (tr.getInputProperty() != null)
           itemType = tr.getInputProperty();
        
        return itemType;
    }

}
