package org.jharks.workflow.loaders;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jharks.workflow.LoaderConfig;
import org.jharks.workflow.QueueNode;
import org.jharks.workflow.QueueWrapper;
import org.jharks.workflow.Queueable;
import org.jharks.workflow.ResponseSet;
import org.jharks.workflow.SessionHistory;


/**
 * Queues a response set as a single category node.
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class CategoryQueueLoader extends AbstractQueueLoader {

    /** The logger for the loader. */
    protected Log logger = LogFactory.getLog(getClass().getName());
    
    /**
     * The method adds one element to the stack for the entire response set.
     * The stacked object is the entire <CODE>ResponseSet</CODE> instance.
     * Expects the itemType and nodeValue attributes to be set on the <code>
     * LoaderConfig</code> instance. 
     * 
     * @param rs the <CODE>ResponseSet</CODE> to be processed.
     * @param sh a <code>SessionHistory</code> instance.
     * @param config a <code>LoaderConfig</code> instance.
     * @see org.jharks.workflow.Loader#load(ResponseSet, SessionHistory, 
     *      LoaderConfig)
     */
    public void load(ResponseSet rs, SessionHistory sh, LoaderConfig config) {
        
        QueueWrapper sElement = null;
        boolean stack = false;
        
        String itemType = config.getItemType();
        
        //Create node to place on queue.
        QueueNode qn = new QueueNode(itemType, config.getNodeValue());
        
        //If no queues on stack yet or top queue not same
        //then add new queue
        if (sh.isStackEmpty() ||
             (!(sh.peek().getElementType().equalsIgnoreCase(itemType)))) {
            sElement = new QueueWrapper(itemType);
            sElement.add(qn);
            stack = true;
        } else {
            //Category name same as top queue on stack so add to queue.
            sElement = (QueueWrapper) sh.peek();
            //Add node to queue
            sElement.add(qn);
        }
        
        //Add queue to stack 
        if ( stack ) sh.stackElement(sElement);
    }
    
    public void load(ResponseSet rs, SessionHistory sh, Queueable tr) {
        String itemType = setType(tr);
        
        LoaderConfig lc = new LoaderConfig(itemType, null, 
               tr.getInputValue(), tr.getFilters());
       
       load(rs, sh, lc);
    }

}
