package org.jharks.workflow.loaders;

import java.util.Collection;
import java.util.Iterator;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jharks.workflow.LoaderConfig;
import org.jharks.workflow.QueueNode;
import org.jharks.workflow.QueueWrapper;
import org.jharks.workflow.Queueable;
import org.jharks.workflow.ResponseSet;
import org.jharks.workflow.SessionHistory;


/**
 * Queues a response set by adding a node for each question amswer
 * group represented in the response set.
 * 
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class QuestionQueueLoader extends AbstractQueueLoader {

    /** The logger for the loader. */
    protected Log logger = LogFactory.getLog(getClass().getName());
    
    /**
     * Iterates over the question ids in the <CODE>ResponseSet</CODE> object
     * and adds an element to the queue for each question id.  The stacked 
     * object represents the question id. The question id can be later used
     * to retrieve responses from the <CODE>SessionHistory</CODE> instance.
     * @param rs the <CODE>ResponseSet</CODE> to be processed.
     * @see org.jharks.workflow.Loader#load(ResponseSet, SessionHistory, 
     *      LoaderConfig)
     */
    public void load(ResponseSet rs, SessionHistory sh, LoaderConfig config) {
      
        Collection<String> questionIds = rs.getQuestionIds();  
        
        QueueWrapper sElement = null;
        boolean stack = false;
        
        String itemType = config.getItemType();
        
        if (sh.isStackEmpty() ||
          (!(sh.peek().getElementType().equalsIgnoreCase(itemType)))) {
          //Create new queue with specified name
          sElement = new QueueWrapper(itemType);
          stack = true;
        } else {
          //Category name same as top queue on stack so add to queue.
          sElement = (QueueWrapper) sh.peek();
        }
      
        for (Iterator<String> it=questionIds.iterator(); it.hasNext(); ) {
          String id = it.next();
          QueueNode qn = new QueueNode(id, null);
          sElement.add(qn);
        }
      
        //Add queue to stack 
        if ( stack ) sh.stackElement(sElement);      
    }
    
    public void load(ResponseSet rs, SessionHistory sh, Queueable tr) { 
        String itemType = setType(tr);
        
        LoaderConfig lc = new LoaderConfig(itemType);
        load(rs, sh, lc);
     }
}
