package org.jharks.workflow.rules;

import java.util.ArrayList;
import java.util.List;

import org.jharks.workflow.Rule;
import org.jharks.workflow.RuleCondition;


/**
 * Generic <CODE>Rule</CODE> implementation that simply iterates over
 * the <CODE>RuleCondition</CODE> instances as an OR evaluator.  The 
 * <CODE>checkRule</CODE> method will evaluate as true if a single 
 * condition is met.
 * 
 * @author Michel J. Rizzo
 */
public class GenericOrRule extends Rule {

    /** conditions available on rule instance */
    private ArrayList<RuleCondition> conditions;
    
    /** default public constructor that initializes conditions list. */
    public GenericOrRule() {
        conditions = new ArrayList<RuleCondition>();
    }
    
    /**
     * Checks rule properties against supplied input to see if 
     * rule must be applied.
     * @see org.jharks.workflow.Rule#checkRule(java.lang.Object)
     */
    public boolean checkRule(Object input) {
        for (int i=0; i < conditions.size(); i++) {
            RuleCondition rc = (RuleCondition) conditions.get(i);
            if (rc.checkCondition(input)) 
                return true;
        }
        
        return false;
    }

    /**
     * Add <CODE>RuleCondition</CODE> instance to <CODE>Rule</CODE>. 
     * @see org.jharks.workflow.Rule#addRuleCondition(
     *      org.jharks.workflow.RuleCondition)
     */
    public void addRuleCondition(RuleCondition rc) {
        conditions.add(rc);
    }
    
    /**
     * Retrieve conditions of the <CODE>Rule</CODE> instance.
     * @return the conditions.
     */
    public List<RuleCondition> getRuleConditions() {
        return conditions;
    }
}
