package org.jharks.workflow.util;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jharks.workflow.AnswerContext;
import org.jharks.workflow.AnswerProperty;
import org.jharks.workflow.SessionHistory;
import org.jharks.workflow.Stackable;


/**
 * Utility class that builds <code>AnswerContext</code> instances
 * based on the state of the pending queues on the 
 * <code>SessionHistory</code> instance.
 * @author Michael J. Rizzo
 * @version 1.0
 */
public class ContextInspector {
    
    /** The logger for the module. */
    protected static Log logger = LogFactory.getLog(ContextInspector.class);
    
    /**
     * Utility method to construct current <CODE>AnswerContext</CODE>.
     * The method inspects a <CODE>SessionHistory</CODE> instance and
     * determines the position within loops. 
     *  
     * @param history a <CODE>SessionHistory</CODE> instance.
     * @return the current context.
     */
    public static AnswerContext retrieveContext(SessionHistory history) {
        AnswerContext context = new AnswerContext();
        
        if (history.isStackEmpty()) 
            return context;
        
        int nodes = history.stackSize();
        for (int i=0; i < nodes; i++) {
            Stackable queue = (Stackable) history.peek(i);
            String queueName = queue.getElementType();
            String value = (String) history.getProperty(queueName);
            if(queueName != null && value == null) 
              continue;
              
            if (logger.isDebugEnabled()) 
              logger.debug("Inspecting the context: node [" + i + "]" +
                      ": node name = [" + queueName + "] " +
                      ": node value = [" + value + "] ");
            context.addProperty(new AnswerProperty(queueName, value));
        }
        
        
        if (logger.isDebugEnabled()) {
            logger.debug("Current context = " + context.toString());
        }
        return context;
    }

}
