package org.jharks.workflow.util;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import org.apache.log4j.Logger;
import org.jharks.workflow.exception.WorkFlowException;

/**
 * Utility for making deep copies (vs. clone()'s shallow copies) of
 * objects. Objects are first serialized and then deserialized. 
 * If an object is encountered that cannot be serialized (or that references an object
 * that cannot be serialized) then a WorkFlowException runtime exception is thrown.
 */
public class ObjectCopier {

	/** The log for the class. */
	private static Logger logger = Logger.getLogger(ObjectCopier.class);
	
    /**
     * Returns a copy of the object, or null if the object cannot
     * be serialized.
     */
    public static Object copy(Object orig) {
        Object obj = null;
        try {
            // Write the object out to a byte array
            FastByteArrayOutputStream fbos =
                    new FastByteArrayOutputStream();
            ObjectOutputStream out = new ObjectOutputStream(fbos);
            out.writeObject(orig);
            out.flush();
            out.close();

            // Retrieve an input stream from the byte array and read
            // a copy of the object back in.
            ObjectInputStream in =
                new ObjectInputStream(fbos.getInputStream());
            obj = in.readObject();
        }
        catch(IOException e) {
        	logger.error("Error occurred in performing deep copy of object", e);
            throw new WorkFlowException("Error occurred in performing deep copy of object", e);
        }
        catch(ClassNotFoundException cnfe) {
        	logger.error("Error occurred in performing deep copy of object [class not found]", cnfe);
            throw new WorkFlowException("Error occurred in performing deep copy of object [class not found]", cnfe);
        }
        return obj;
    }

}


