/**
 * 
 */
package org.jharks.workflow.util;

import java.io.Serializable;

/**
 * A key generator that uses the RandomGuid support class. The default
 * implementation used by the webflow system.
 * 
 * @author Michael J. Rizzo
 *
 */
public class RandomGuidUidGenerator implements UidGenerator, Serializable {

    /**
	 * Serial version uid.
	 */
	private static final long serialVersionUID = 1L;
	
	/**
     * Should the random GUID generated be secure?
     */
    private boolean secure;

    /**
     * Returns whether or not the generated random numbers are
     * <i>secure</i>, meaning cryptographically strong.
     */
    public boolean isSecure() {
        return secure;
    }

    /**
     * Sets whether or not the generated random numbers should be
     * <i>secure</i>. If set to true, generated GUIDs are cryptographically
     * strong.
     */
    public void setSecure(boolean secure) {
        this.secure = secure;
    }

    public Serializable generateUid() {
        return new RandomGuid(secure).toString();
    }

    public Serializable parseUid(String encodedUid) {
        return encodedUid;
    }

}
