package org.jharks.workflow.util;

import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jharks.workflow.BaseWorkFlowManagerImpl;
import org.jharks.workflow.WorkFlowConfig;


import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;


/**
 * An entity resolver used to allow DTD files to be specified using path relative to the 
 * user directory (NOT the directory where the XML file is located).
 */
public class WorkFlowEntityResolver implements EntityResolver { 

    /** The logger for the module. */
    protected Log logger = LogFactory.getLog(getClass().getName());
    
    /** The configuration file. */
    private static WorkFlowConfig config = WorkFlowConfig.getInstance();
    
    /** The "file://" prefix. */
    private static final String FILE_PREFIX = "file://";
    
    /** The ".dtd" suffix. */
    private static final String DTD_SUFFIX = ".dtd";
    
    /**
     * Replaces the DTD entity, specified as a relative path, with a full path to the
     * DTD file.
     * 
     * @param publicId the public ID of the entity.
     * @param systemId the system ID of the entity.
     * 
     * @return an InputSource specifying the location of the DTD. 
     */
    public InputSource resolveEntity(String publicId, String systemId)
            throws SAXException, IOException {
        
        String relativePath;
        if (logger.isDebugEnabled())
            logger.debug("In EntityResolver: resolving " + systemId);
        
        if (systemId != null && systemId.equals("file://workflow.dtd")) {
            if (logger.isDebugEnabled())
                logger.debug("In EntityResolver: resolving workflow.dtd");
            InputStream is = BaseWorkFlowManagerImpl.class.getResourceAsStream("workflow.dtd");
                
            return new InputSource(is);
            
            
        } else if (systemId != null && systemId.startsWith(FILE_PREFIX) && 
                systemId.endsWith(DTD_SUFFIX)) {
            relativePath = systemId.substring(FILE_PREFIX.length());
            
        } else {
            relativePath = systemId;
        }
        
        relativePath = config.getProperty("xml-base-directory") + 
                       System.getProperty("file.separator") + 
                       relativePath;
        
        return new InputSource(relativePath);
    }

}
